pyxmpp.jabber.muc

Package pyxmpp :: Package jabber :: Module muc |
[hide private]

# Module muc

source code

Jabber Multi-User Chat implementation.

Normative reference:
  - JEP 45

Classes | [hide private]
| MucRoomHandler Base class for MUC room handlers.
| MucRoomUser Describes a user of a MUC room.
| MucRoomState Describes the state of a MUC room, handles room events and provides an interface for room actions.
| MucRoomManager Manage collection of MucRoomState objects and dispatch events.

Variables | [hide private]
| __revision__ = ``'``$Id: muc.py 714 2010-04-05 10:20:10Z jajcus $``'``
| __package__ = ``'``pyxmpp.jabber``'``

Imports: logging, Presence, Message, Iq, JID, xml_element_ns_iter, MucPresence, MucUserX, MucItem, MucStatus, MUC_OWNER_NS, DATAFORM_NS, Form, weakref